@@ -776,7 +776,8 @@ static int read_depfile(void)
 	struct stat statbuf;
 	int ret = 0;
 	int line_no;
-	char buf[3000];
+	int sizebuf;
+	char *buf = NULL;
 	const char *depfile = gen_file[GEN_DEPFILE].name;
 
 	if ((fin = fopen(depfile, "r")) == NULL) {
@@ -794,9 +795,9 @@ static int read_depfile(void)
 			config_file, depfile);
 #endif
 
-	while (fgets_strip(buf, sizeof(buf) - 1, fin, &line_no) != NULL) {
+	while (fgets_strip(&buf, &sizebuf, fin, &line_no) != NULL) {
 		NODE *nod;
-		char line[sizeof(buf)];
+		char line[sizebuf];
 		char *pt;
 		char *modname;
 		int len = strlen(buf);
@@ -1425,7 +1426,7 @@ static int modprobe_fromlist(int argc, char *argv[], char *type, int loadall)
 	if (ret == -2) {
 		if (error_name && error_name != name)
 			error("Can't locate module %s which is needed for %s", error_name, name);
-		else
+		else if (!quiet)
 			error("Can't locate module %s", name);
 	}
 	else
