@@ -21,8 +21,6 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_load.c 1.4 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
-
 #include <alloca.h>
 #include <string.h>
 #include <stdlib.h>
@@ -240,8 +238,27 @@ obj_load (int fp, Elf32_Half e_type, const char *filename)
 		else
 		  name = f->sections[sym->st_shndx]->name;
 
-		obj_add_symbol(f, name, j, sym->st_info, sym->st_shndx,
-			       sym->st_value, sym->st_size);
+                {
+#ifdef ARCH_sh64
+
+		  /*
+		   * For sh64 it is possible that the target of a branch requires a 
+		   * mode switch---32 to 16 and back again---and this is implied by
+		   * the lsb being set in the target address for SHmedia mode and clear
+		   * for SHcompact. 
+		   */
+                  int lsb;
+                  lsb = (sym->st_other & 4) ? 1 : 0;
+
+		  obj_add_symbol(f, name, j, sym->st_info,
+				 sym->st_shndx,
+				 sym->st_value | lsb, sym->st_size);
+#else
+		  obj_add_symbol(f, name, j, sym->st_info,
+				 sym->st_shndx,
+				 sym->st_value, sym->st_size);
+#endif
+                }
 
 	      }
 	  }
