@@ -19,8 +19,6 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_reloc.c 1.4 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
-
 #include <string.h>
 #include <assert.h>
 #include <alloca.h>
@@ -98,7 +96,8 @@ obj_check_undefineds(struct obj_file *f, int quiet)
 	    else if (sym->r_type) /* assumes R_arch_NONE is 0 on all arch */
 	      {
 		if (!quiet)
-			error("unresolved symbol %s", sym->name);
+			error("%s: unresolved symbol %s",
+			      f->filename, sym->name);
 		ret = 0;
 	      }
 	  }
@@ -319,8 +318,8 @@ obj_relocate (struct obj_file *f, ElfW(Addr) base)
 
 	      if (symndx >= nsyms)
 		{
-		  error("Bad symbol index: %08lx >= %08lx",
-			symndx, nsyms);
+		  error("%s: Bad symbol index: %08lx >= %08lx",
+			f->filename, symndx, nsyms);
 		  continue;
 		}
 
@@ -351,7 +350,7 @@ obj_relocate (struct obj_file *f, ElfW(Addr) base)
 	      errmsg = "Modules compiled with -mconstant-gp cannot be loaded";
 	      goto bad_reloc;
 	    bad_reloc:
-	      error("%s of type %ld for %s", errmsg,
+	      error("%s: %s of type %ld for %s", f->filename, errmsg,
 		    (long)ELFW(R_TYPE)(rel->r_info), intsym->name);
 	      ret = 0;
 	      break;
