@@ -30,6 +30,10 @@
 #include <obj.h>
 #include <util.h>
 
+/* older glibc versions had a wrong name for R_390_GOTOFF32 */
+#ifndef R_390_GOTOFF32
+#define R_390_GOTOFF32 R_390_GOTOFF
+#endif
 
 /*======================================================================*/
 
@@ -204,7 +208,7 @@ arch_apply_relocation (struct obj_file *f,
         *(unsigned int *) loc += isym->gotent.offset;
       break;
 
-    case R_390_GOTOFF:
+    case R_390_GOTOFF32:
       assert(got != 0);
       *loc += v - got;
       break;
@@ -264,7 +268,7 @@ arch_create_got (struct obj_file *f)
             /* The next three don't need got entries but the address
                of the got itself.  */
 	    case R_390_GOTPC:
-	    case R_390_GOTOFF:
+	    case R_390_GOTOFF32:
 	      gotneeded = 1;
               break;
 
@@ -277,7 +281,7 @@ arch_create_got (struct obj_file *f)
               if (!ge->allocated) {
                 ge->allocated = 1;
                 ge->offset = got_offset;
-                got_offset += sizeof(void*);
+                got_offset += sizeof(tgt_long);
               }
 	      break;
 
