@@ -87,6 +87,7 @@ char *aliaslist[] =
 	"block-major-91 ide-probe-mod",
 	"block-major-93 nftl",		/* from David Woodhouse <dwmw2@infradead.org> */
 	"block-major-97 pg",
+	"block-major-113 viocd",
 
 #if !defined(__s390__) && !defined(__s390x__)
 	"char-major-4 serial",
@@ -117,8 +118,11 @@ char *aliaslist[] =
 	"char-major-10-157 applicom",	/* from David Woodhouse <dwmw2@infradead.org> */
 	"char-major-10-175 agpgart",    /* /dev/agpgart GART AGP mapping access */
 	"char-major-10-184 microcode",	/* Tigran Aivazian <tigran@veritas.com> */
+	"char-major-10-200 tun",	/* Universal TUN/TAP device driver */
+	"char-major-10-250 hci_vhci",
 
 	"char-major-13 input",
+	"char-major-13-0 joydev",
 	"char-major-13-32 mousedev",
 	"char-major-14 soundcore",
 	"char-major-19 cyclades",
@@ -126,7 +130,7 @@ char *aliaslist[] =
 	"char-major-21 sg",
 	"char-major-22 pcxx", /* ?? */
 	"char-major-23 pcxx", /* ?? */
-	"char-major-27 ftape",
+	"char-major-27 zftape",
 	"char-major-34 scc",
 	"char-major-35 tclmidi",
 	"char-major-36 netlink",
@@ -144,7 +148,10 @@ char *aliaslist[] =
 	"char-major-109 lvm-mod",
 	"char-major-161 ircomm-tty",
 	"char-major-171 raw1394",
+	"char-major-195 NVdriver",
 	"char-major-200 vxspec",
+	"char-major-206 osst",  /* OnStream SCSI tape */
+	"char-major-216 rfcomm",
 
 	"dos msdos",
 	"dummy0 dummy",
@@ -167,12 +174,32 @@ char *aliaslist[] =
 				/* PF_AAL5	8  Reserved for Werner's ATM */
 				/* PF_X25	9  Reserved for X.25 project */
 	"net-pf-10 off",	/* PF_INET6	10 IP version 6 */
+	"net-pf-15 af_key",	/* PF_KEY       15 Key Management API */
 
 	/* next two from <dairiki@matthews.dairiki.org>  Thanks! */
 	"net-pf-17 af_packet",
 	"net-pf-19 off",	/* acorn econet */
+	
+	"net-pf-31 bluez",
 
 	"netalias-2 ip_alias",
+
+	/* To be able to attach some dongles */
+	"irlan0 irlan",
+	"irda-dongle-0 tekram",
+	"irda-dongle-1 esi",
+	"irda-dongle-2 actisys",
+	"irda-dongle-3 actisys",
+	"irda-dongle-4 girbil",
+	"irda-dongle-5 litelink",
+	"irda-dongle-6 airport",
+	"irda-dongle-7 old_belkin",
+	 
+	"bt-proto-0 l2cap",
+	"bt-proto-2 sco",
+	"bt-proto-3 rfcomm",
+	"bt-proto-4 bnep",
+
 	"plip0 plip",
 	"plip1 plip",
 	"tunl0 ipip",
@@ -194,8 +221,9 @@ char *aliaslist[] =
 	"slip1 slip",
 	"tty-ldisc-1 slip",
 	"tty-ldisc-3 ppp_async",
-	"tty-ldisc-11 irtty",
+	"tty-ldisc-11 irtty", /* IrDA over a normal serial port, or a serial port compatible IrDA port */
 	"tty-ldisc-14 ppp_synctty",
+	"tty-ldisc-15 hci_uart",
 	"ppp-compress-18 ppp_mppe",
 	"ppp-compress-21 bsd_comp",
 	"ppp-compress-24 ppp_deflate",
@@ -209,6 +237,18 @@ char *aliaslist[] =
 
 	"usbdevfs usbcore",
 
+	"xfrm-type-2-50 esp4",
+	"xfrm-type-2-51 ah4",
+	"xfrm-type-2-108 ipcomp",
+	"xfrm-type-10-50 esp6",
+	"xfrm-type-10-51 ah6",
+	"xfrm-type-10-108 ipcomp6",
+
+	"cipher_null crypto_null",
+	"digest_null crypto_null",
+	"compress_null crypto_null",
+	"sha384 sha512",
+
 	NULL			/* marks the end of the list! */
 };
 
@@ -231,6 +271,9 @@ char *optlist[] =
  */
 char *above[] =
 {
+	"hid keybdev mousedev",
+	"usbmouse hid",
+	"wacom evdev",
 	NULL			/* marks the end of the list! */
 };
 
@@ -241,6 +284,7 @@ char *above[] =
  */
 char *below[] =
 {
+	"ov518_decomp ov511",
 	NULL			/* marks the end of the list! */
 };
 
@@ -252,6 +296,7 @@ char *below[] =
 char *prune[] =
 {
 	"modules.dep",
+	"modules.description",
 	"modules.generic_string",
 	"modules.pcimap",
 	"modules.isapnpmap",
@@ -261,6 +306,7 @@ char *prune[] =
 	"modules.pnpbiosmap",
 	"System.map",
 	".config",
+	"Kerntypes",
 	"build",		/* symlink to source tree */
 	"vmlinux",
 	"vmlinuz",
